==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Input/wavpack/translations/wavpack_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Greffon WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Fichiers WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>About WavPack Audio Plugin</source>
        <translation>À propos du greffon audio WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="156"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Greffon audio WavPack pour Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>WavPack library version:</source>
        <translation>Version de la bibliothèque WavPack :</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="159"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="65"/>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
        <source>Sample rate</source>
        <translation>Taux d&apos;échantillonage</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="66"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="67"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>Bitrate</source>
        <translation>Débit binaire</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="68"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Ratio</source>
        <translation>Taux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/wavpack/translations/wavpack_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>Greffon WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>Fichiers WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="153"/>
        <source>About WavPack Audio Plugin</source>
        <translation>À propos du greffon audio WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="154"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Greffon audio WavPack pour Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>WavPack library version:</source>
        <translation>Version de la bibliothèque WavPack :</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation>Taux d&apos;échantillonage</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation>Débit binaire</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation>Taux</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>
